#
# spec file for package sphinx
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global sphinx_user sphinx
%global sphinx_group sphinx
%global daemon searchd
%global sphinx_home %{_localstatedir}/lib/sphinx
%global soname 0_0_1
# For being able to build for SLE_11
%{!?_tmpfilesdir:%global _tmpfilesdir %{_prefix}/lib/tmpfiles.d}
Name:           sphinx
Version:        2.2.11
Release:        10.2
Summary:        SQL full-text search engine
License:        GPL-2.0-only
Group:          Productivity/Databases/Servers
URL:            https://sphinxsearch.com/
Source0:        https://sphinxsearch.com/files/%{name}-%{version}-release.tar.gz
Source1:        %{daemon}.service
Source2:        %{daemon}.init
Source3:        %{name}-user.conf
Patch0:         obs.patch
Patch2:         sphinx-default_listen.patch
Patch3:         reproducible.patch
#CVE-2020-29050 https://salsa.debian.org/debian/sphinxsearch/-/blob/4d6fe40644130308604845db43d3588e715ec85d/debian/patches/06-CVE-2020-29050.patch
Patch4:         CVE-2020-29050.patch
Patch5:         sphinx-gcc14.patch
# for fix-ups
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  libmariadb-devel
BuildRequires:  pkgconfig
BuildRequires:  shadow
BuildRequires:  systemd-rpm-macros
BuildRequires:  sysuser-tools
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(libecpg) >= 9.6
BuildRequires:  pkgconfig(libecpg_compat) >= 9.6
BuildRequires:  pkgconfig(libpgtypes) >= 9.6
BuildRequires:  pkgconfig(libpq) >= 9.6
Requires:       logrotate
Requires(pre):  %fillup_prereq
Provides:       %{daemon}
%{?systemd_ordering}
%sysusers_requires

%description
Sphinx is a standalone search engine providing size-efficient and
relevant full-text search functions to other applications. Sphinx
integrates with SQL databases and scripting languages.

Data source drivers support fetching data either via direct
connection to MySQL, PostgreSQL, or from a pipe in a custom XML
format.

The Search API is natively ported to PHP, Python, Perl, Ruby, Java,
and also available as a pluggable MySQL storage engine.

Sphinx is an acronym which is officially decoded as SQL Phrase Index.

%package -n libsphinxclient-%{soname}
Summary:        Pure C searchd client API library
Group:          System/Libraries

%description -n libsphinxclient-%{soname}
Pure C searchd client API library
Sphinx search engine, http://sphinxsearch.com/

%package -n libsphinxclient-devel
Summary:        Development libraries and header files for libsphinxclient
Group:          Development/Libraries/Other
Requires:       libsphinxclient-%{soname} = %{version}-%{release}

%description -n libsphinxclient-devel
Provides necessary development files for sphinx api and shared libs for sphinx client.
Pure C searchd client API library
Sphinx search engine, http://sphinxsearch.com/


# Comment
# we don't package api language java,ruby,php,python
# upstream don't recommend their usage.
%prep
%setup -q -n "%{name}-%{version}-release"
%autopatch -p1

find -type d -name CVS -exec rm -Rf {} +

%build
%sysusers_generate_pre %{SOURCE3} %{name} %{name}-user.conf
#@todo we should move it to cmake
set -x
export pg_includes="$(pkg-config --cflags --libs libpq | sed 's,^-I,,g')"

%configure --sysconfdir=%{_sysconfdir}/%{name}/ \
    --enable-id64 \
    --with-mysql \
    --with-pgsql \
    --with-pgsql-includes="${pg_includes}" \
    --with-pgsql-libs="%{_libdir}"

%make_build

pushd api/libsphinxclient
 %configure --sysconfdir=%{_sysconfdir}/%{name}/
 %make_build -j1
popd

%install
%make_install VERBOSE=1 %{?_smp_mflags}

pushd api/libsphinxclient
 %make_install VERBOSE=1 %{?_smp_mflags}
popd

find %{buildroot} "(" -name "*.a" -o -name "*.la" ")" -print -delete

# Create /var/log/sphinx
mkdir -p %{buildroot}%{_localstatedir}/log/%{name}
touch %{buildroot}%{_localstatedir}/log/%{name}/query.log
touch %{buildroot}%{_localstatedir}/log/%{name}/%{daemon}.log

# Create /var/run/sphinx
mkdir -p %{buildroot}/run/%{name}

# Create /var/lib/sphinx
mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}/data/index

# etc/sphinx.conf preparation
# Adjust sphinx*.conf.dist to our location
for CONF in %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf.dist\
 %{buildroot}%{_sysconfdir}/%{name}/%{name}-min.conf.dist;
do
 sed -i 's|%{_localstatedir}/log/%{daemon}.log|%{_localstatedir}/log/%{name}/%{daemon}.log|g' ${CONF}
 sed -i 's|%{_localstatedir}/log/query.log|%{_localstatedir}/log/%{name}/query.log|g' ${CONF}
 sed -i 's|%{_localstatedir}/log/%{daemon}.pid|/run/%{name}/%{daemon}.pid|g' ${CONF}
 sed -i 's|%{_localstatedir}/data|%{_localstatedir}/lib/%{name}/data|g' ${CONF}
done

cp -v %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf{.dist,}

# Create /etc/logrotate.d/sphinx
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
cat > %{buildroot}%{_sysconfdir}/logrotate.d/%{name} << EOF
%{_localstatedir}/log/%{name}/*.log {
       weekly
       rotate 10
       copytruncate
       delaycompress
       compress
       notifempty
       missingok
       su %{sphinx_user} %{sphinx_group}
       create 640 %{sphinx_user} %{sphinx_group}
}
EOF

# Create /usr/tempfiles.d/sphinx
mkdir -p %{buildroot}%{_tmpfilesdir}
cat > %{buildroot}%{_tmpfilesdir}/%{name}.conf << EOF
d /run/%{name} 755 sphinx root -
EOF

# systemd vs SysVinit
mkdir -p %{buildroot}%{_sbindir}
install -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/%{daemon}.service
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{daemon}

# install user
mkdir -p %{buildroot}%{_sysusersdir}
install -m 644 %{SOURCE3} %{buildroot}%{_sysusersdir}/

%pre
getent group %{sphinx_group} >/dev/null || groupadd -r %{sphinx_group}
getent passwd %{sphinx_user} >/dev/null || \
useradd -r -g %{sphinx_group} -d %{sphinx_home} -s /bin/sh \
-c "Sphinx Searchd daemon" %{sphinx_user}
%service_add_pre %{daemon}.service

%post
%service_add_post %{daemon}.service
%{_bindir}/systemd-tmpfiles --create %{_tmpfilesdir}/%{name}.conf || true

%preun
%service_del_preun %{daemon}.service
%{_bindir}/systemd-tmpfiles --remove %{_tmpfilesdir}/%{name}.conf || true

%postun
%service_del_postun %{daemon}.service

%post -n libsphinxclient-%{soname} -p /sbin/ldconfig
%postun -n libsphinxclient-%{soname} -p /sbin/ldconfig

%files
%config %dir %{_sysconfdir}/%{name}
%{_sysusersdir}/%{name}-user.conf
%config %{_sysconfdir}/%{name}/example.sql
# Restrict rights access to conf files, because they can contain sql db credentials
%config(noreplace) %attr(640,root,%{sphinx_group}) %{_sysconfdir}/%{name}/%{name}.conf
%config %{_sysconfdir}/%{name}/%{name}.conf.dist
%config %{_sysconfdir}/%{name}/%{name}-min.conf.dist
%{_unitdir}/%{daemon}.service
%{_tmpfilesdir}/%{name}.conf
%ghost /run/%{name}
%{_sbindir}/rc%{daemon}
%config %{_sysconfdir}/logrotate.d/%{name}
%{_bindir}/spelldump
%{_bindir}/indexer
%{_bindir}/searchd
%{_bindir}/indextool
%{_bindir}/wordbreaker
%license COPYING
%doc contrib/
%doc doc/*.html doc/*.css doc/*.txt
%{_mandir}/man1/indexer.1*
%{_mandir}/man1/indextool.1*
%{_mandir}/man1/searchd.1*
%{_mandir}/man1/spelldump.1*
%dir %attr(0750, %{sphinx_user}, %{sphinx_group}) %{_localstatedir}/log/%{name}
%ghost %attr(0640, %{sphinx_user}, root) %{_localstatedir}/log/%{name}/%{daemon}.log
%ghost %attr(0640, %{sphinx_user}, root) %{_localstatedir}/log/%{name}/query.log
%dir %attr(0755, %{sphinx_user}, %{sphinx_group}) %{_localstatedir}/lib/%{name}
%dir %attr(0755, %{sphinx_user}, %{sphinx_group}) %{_localstatedir}/lib/%{name}/data
%dir %attr(0755, %{sphinx_user}, %{sphinx_group}) %{_localstatedir}/lib/%{name}/data/index

%files -n libsphinxclient-%{soname}
%license COPYING
%{_libdir}/libsphinxclient-0.0.1.so

%files -n libsphinxclient-devel
%license COPYING
%{_includedir}/sphinxclient.h
%{_libdir}/libsphinxclient.so

%changelog
* Mon Dec  2 2024 Friedrich Haubensak <hsk17@mail.de>
- add sphinx-gcc14.patch to fix gcc14 compile time error
* Tue Jan  9 2024 Jan Engelhardt <jengelh@inai.de>
- Fix weird restrictive permissions (0640) on files in /usr
  and make it 0644 like everything else in the system.
* Mon Sep 25 2023 Bruno Friedmann <bruno@ioda-net.ch>
- Move user/group to systemd-user way.
- spec-cleaner
* Thu May 12 2022 Jan Engelhardt <jengelh@inai.de>
- Add permissions on /var/log/sphinx so it can create searchd.log.
* Thu Jan 27 2022 Bruno Friedmann <bruno@ioda-net.ch>
- Added CVE-2020-29050.patch for fixing CVE-2020-29050 boo#1195227
  Source debian and manticoresearch
- Packaging:
  + Renew with spec-cleaner -m
  + Update copyright year
  + Cleanup older suse version %%if construct
  + Use libmariadb-devel instead mysql-devel
  + Use %%autopatch
* Sun Jul 26 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Spec cleaner minimal update date
- Minor cosmetic changes
- Close boo#1157590
  + Remove posttrans section with chown
    On systems with fs.protected_hardlinks=0 this allows sphinx
    to escalate to root.
  + Add log directory and files to files section
* Sat Mar 23 2019 Jan Engelhardt <jengelh@inai.de>
- Reduce scriptlets' hard dependency on systemd.
- Remove wrong "exit 0" from %%pre that precluded %%service_* to run.
* Fri Mar 22 2019 Bruno Friedmann <bruno@ioda-net.ch>
- spec-cleaner minimal https, date, use now pkg-config for deps.
- Fix build failure due to lack of pg_config in postgresql11-devel
  use pkg-config libpq in all case.
* Wed Aug  8 2018 jengelh@inai.de
- Trim redundancies and bias from description.
- Fix RPM groups. Use more efficient find calls in .spec.
* Mon Jul 23 2018 bwiedemann@suse.com
- Add reproducible.patch to drop hostname and kernel version
  from package build result (boo#1084909, boo#1101107)
* Thu Jun 14 2018 mvetter@suse.com
- Replace require libsphinxclient with libsphinxclient-%%{soname}
  for libsphinxclient-devel
* Sun Sep 18 2016 bruno@ioda-net.ch
- Update to last maintenance release
  with over 70 bug fixes and small improvements:
  * max_matches option did not affect facet queries #2348
  * support for Connector/J 5.1.36+ #2365
  * UTF-8 support for extended wildcards (?,%%) #2451
  * group by aliased  for JSON array #2452
  * multi query with profiling enabled #2394
  * ping to bad ha mirror pause accept thread at daemon #2363
  * windows service does not handle system shutdown #2497
  * 64-bit values comparison for ALL/ANY/INDEXOF functions #2437
  * count(*) statement vs space characters at facet #2420
  * better SphinxQL logs #2462, #2435
  * lcs calculation for large delta position #2398
  * official packages for Ubuntu 16.04 LTS
  * added missing logrotate for some Debian/Ubuntu packages
  * Ubuntu 16.04, Debian Jessie, RHEL/CentOS 7 packages use systemd
    service script
    For a complete list, please consult the changelog.
    http://sphinxsearch.com/docs/latest/rel2211.html
- Packaging :
  * Fix missing postun for libsphinx
  * Added ghost /run/sphinx
* Sun Sep 20 2015 bruno@ioda-net.ch
- Removed unneeded patch sphinx-fix_static.patch
- Fix packaging and build issues : add systemd requires when needed
* Sat Sep 19 2015 p.drouand@gmail.com
- Update to version 2.2.10
  * added #2310, --replay-flags=ignore-open-errors switch to replay
    binlogs even if some files are missing
  * added #2234, support for empty string values (stringattr='') in
    WHERE clause
  * added #2233, support for IN() filters with string values
  * added #2232, string collation support in SELECT expressions
  * added #2121, "where flt<>val" support, "where fltcol=intval" and
    "where fltcol!=intval" conditions
  * added #2119, new indexer exit code 2 on a --rotate failure
  * fixed #2207, unified min_prefix_len, min_infix_len behavior
    between RT and plain indexes
  * fixed #2020, unified (and greatly shortened) the list of SphinxQL
    reserved keywords between indexer checks, SphinxQL parser checks,
    and the documentation
- Add patches
  * sphinx-default_listen.patch
  * sphinx-fix_static.patch
- Remove copying.patch
* Sat May 23 2015 bruno@ioda-net.ch
- Packaging Fixes
  * systemd unit file : no forking, add group
  * correct rights for conf file root,daemon_group in /etc/sphinx
  * correct rights for log dir & files
  * ghost log files
  * Fix path and name in .dist conf file too
  * Create correct directories layout in /var/lib/sphinx
  * Fix /run/sphinx creation and remove at (un)install time
* Thu May 14 2015 bruno@ioda-net.ch
- Update to last 2.2.9 bugfixes release
  * fixed #2190, incorrect GROUP BY outer JSON object
  * fixed #2197, TRUNCATE fails to remove disk chunk files after calling OPTIMIZE
  * fixed #2199, invalid packedfactors JSON output for index with stopwords
  * fixed #2203, legacy API SELECT list
  * fixed #2201, crash with string comparison at expressions and expression ranker
  * fixed #2196, .NET connector issue (UTC_TIMESTAMP() support)
  * fixed #2144, query parser crash vs multiforms with heading numbers
  * fixed #2228, removed searchd shutdown behavior on failed connection
  * fixed #2220, aliased JSON elements support
  * fixed #2122, id64 daemon failed to load RT disk chunk with kill-list from id32 build
  * fixed #2208, ZONESPANLIST() support for RT indexes
  * fixed #1979, snippets generation and span length and lcs calculation in proximity queries
  * fixed truncated results (and a potential crash) vs long enough ZONESPANLIST() result
- Packaging:
  * run spec-cleaner
  * * Adapted Year licence
  * * changes to make macros
  * Patch for FSF COPYING
  * split daemon and libclient apply soname policy
  * include systemd service or init file depending on suse version
  * include logrotate file
  * Adapt conf to new data,log,pid dir
* Fri Mar 20 2015 hvogel@suse.com
- Update to 2.2.8
  * Full JSON support.
  * New and easy FACET syntax.
  * ALTER statement for dynamic index manipulation.
  * English and German morphology (lemmatization) support.
  * HAVING and N-best GROUP BY clauses for SELECT queries.
  * A new plugin system (CREATE/DROP PLUGIN, tokenization and
    ranking plugins, etc).
* Fri Jun  6 2014 adrian@suse.de
- update to 2.1.8
* Wed Aug  7 2013 coolo@suse.com
- stop renaming indexer and searchd, 3rd party libraries look
  for it
* Wed Aug  7 2013 coolo@suse.com
- update to 2.0.8
  Bug fixes
  - --------
  * fixed #1515, log strings over 2KB were clipped when
    query_log_format=plain
  * fixed #1514, RT index disk chunk lose attribute update on daemon
    restart
  * fixed #1512, crash while formatting log messages
  * fixed #1511, crash on indexing PostgreSQL data source with MVA
    attributes
  * fixed #1509, blend_chars vs incomplete multi-form and overshort
  * fixed #1504, RT binlog replay vs descending tid on update
  * fixed #1499, sql_field_str2wordcount actually is int, not string
  * fixed #1498, now working with exceptions starting with number too
  * fixed #1496, multiple destination keywords in wordform
  * fixed #1494, lost 'mod', '%%' operations in select list. Also corrected
    few typers in the doc.
  * fixed #1490, expand_keywords vs prefix
  * fixed #1487, `id` in expression fixed
  * fixed #1483, snippets limits fix
  * fixed #1481, shebang config changes check on rotation
  * fixed #1479, port handling in PHP Sphinx API
  * fixed #1474, daemon crash at SphinxQL packet overflows max_packet_size
  * fixed #1472, crash on loading index to indextool for check
  * fixed #1465, expansion_limit got lost in index rotation
  * fixed #1427, #1506, utf8 3 and 4-bytes codepoints
  * fixed #1405, between with mixed int float values
- remove obsolete _service file (still referencing 2.0.6)
* Mon May  6 2013 aldemir.akpinar@gmail.com
- Removed libsphinx client package and moved it to sphinx-devel
* Thu Apr 25 2013 aldemir.akpinar@gmail.com
- update to 2.0.7
- cleanup of spec file
* Fri Feb  8 2013 highwaystar.ru@gmail.com
- update to 2.0.6 release
  Tue Jun  3 03:20:29 GMT 2011 - ctype
- update to 2.0.3-release
  Mon Jun  6 12:17:29 GMT 2011 - ctype
- update to 2.0.1-beta
* Fri Mar 26 2010 aduffeck@novell.com
- update to 0.9.9
* Wed Nov  5 2008 pascal.bleser@opensuse.org
- update to 0.9.8.1
* Mon Nov 19 2007 mrueckert@suse.de
- update to 0.9.7
- enable debug package
* Sat Nov  4 2006 mrueckert@suse.de
- update to 0.9.6 final
